skippa package
==============

Submodules
----------

skippa.pipeline module
----------------------

.. automodule:: skippa.pipeline
   :members:
   :undoc-members:
   :show-inheritance:

skippa.test module
------------------

.. automodule:: skippa.test
   :members:
   :undoc-members:
   :show-inheritance:

skippa.transformers module
--------------------------

.. automodule:: skippa.transformers
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: skippa
   :members:
   :undoc-members:
   :show-inheritance:
